import { DotAnalyticsPayload, PageViewEvent, TrackEvent } from '../shared/dot-content-analytics.model';

/**
 * Plugin that enriches the analytics payload data based on the event type.
 * For page view events, it adds browser data like viewport size, user agent, etc.
 * For track events, it adds custom event properties and standardizes the event format.
 * All events are enriched with source type and anonymous ID if available.
 */
export declare const dotAnalyticsEnricherPlugin: {
    name: string;
    'page:dot-analytics': ({ payload }: {
        payload: DotAnalyticsPayload;
    }) => {
        properties: PageViewEvent;
        type: string;
        event: string;
        options: Record<string, unknown>;
        userId: string | null;
        anonymousId: string | null;
    };
    'track:dot-analytics': ({ payload }: {
        payload: DotAnalyticsPayload;
    }) => {
        properties: TrackEvent;
        type: string;
        event: string;
        options: Record<string, unknown>;
        userId: string | null;
        anonymousId: string | null;
    };
};
