import { DotAnalyticsParams, DotContentAnalyticsConfig } from '../shared/dot-content-analytics.model';

/**
 * Analytics plugin for tracking page views and custom events in DotCMS applications.
 * This plugin handles sending analytics data to the DotCMS server, managing initialization,
 * and processing both automatic and manual tracking events.
 *
 * @param {DotAnalyticsConfig} config - Configuration object containing API key, server URL,
 *                                     debug mode and auto page view settings
 * @returns {Object} Plugin object with methods for initialization and event tracking
 */
export declare const dotAnalytics: (config: DotContentAnalyticsConfig) => {
    name: string;
    config: DotContentAnalyticsConfig;
    /**
     * Initialize the plugin
     */
    initialize: (params: DotAnalyticsParams) => Promise<void>;
    /**
     * Track a page view event
     */
    page: (params: DotAnalyticsParams) => Promise<void>;
    /**
     * Track a custom event
     */
    track: (params: DotAnalyticsParams) => Promise<void>;
    /**
     * Check if the plugin is loaded
     */
    loaded: () => boolean;
};
